@@ -29,6 +29,8 @@ class EssbasicClient(AbstractClient):
     def ChannelBatchCancelFlows(self, request):
         """指定需要批量撤销的签署流程Id，批量撤销合同
         客户指定需要撤销的签署流程Id，最多100个，超过100不处理；接口失败后返回错误信息
+        注意:
+        能撤回合同的只能是合同的发起人或者发起企业的超管、法人
 
         :param request: Request instance for ChannelBatchCancelFlows.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelBatchCancelFlowsRequest`
@@ -56,6 +58,38 @@ class EssbasicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ChannelCancelFlow(self, request):
+        """渠道版撤销签署流程接口
+        仅支持未签署完成的合同
+        注意:
+        能撤回合同的只能是合同的发起人或者发起企业的超管、法人
+
+        :param request: Request instance for ChannelCancelFlow.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCancelFlowRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCancelFlowResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChannelCancelFlow", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ChannelCancelFlowResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ChannelCancelMultiFlowSignQRCode(self, request):
         """此接口（ChannelCancelMultiFlowSignQRCode）用于取消一码多扫二维码。该接口对传入的二维码ID，若还在有效期内，可以提前失效。
 
@@ -87,7 +121,10 @@ class EssbasicClient(AbstractClient):
 
     def ChannelCreateBatchCancelFlowUrl(self, request):
         """指定需要批量撤销的签署流程Id，获取批量撤销链接
-        客户指定需要撤销的签署流程Id，最多100个，超过100不处理；接口调用成功返回批量撤销合同的链接，通过链接跳转到电子签小程序完成批量撤销
+        客户指定需要撤销的签署流程Id，最多100个，超过100不处理；
+        接口调用成功返回批量撤销合同的链接，通过链接跳转到电子签小程序完成批量撤销;
+        注意:
+        能撤回合同的只能是合同的发起人或者发起企业的超管、法人
 
         :param request: Request instance for ChannelCreateBatchCancelFlowUrl.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateBatchCancelFlowUrlRequest`
@@ -115,6 +152,35 @@ class EssbasicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ChannelCreateBoundFlows(self, request):
+        """此接口（CreateConsoleLoginUrl）用于渠道子客领取合同，经办人需要有相应的角色，领取后的合同不能重复领取
+
+        :param request: Request instance for ChannelCreateBoundFlows.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateBoundFlowsRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateBoundFlowsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChannelCreateBoundFlows", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ChannelCreateBoundFlowsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ChannelCreateConvertTaskApi(self, request):
         """渠道创建文件转换任务
 
@@ -145,7 +211,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreateFlowByFiles(self, request):
-        """接口（ChannelCreateFlowByFiles）用于渠道版通过文件创建签署流程。此接口不可直接使用，需要运营申请
+        """接口（ChannelCreateFlowByFiles）用于渠道版通过文件创建签署流程。此接口静默签能力不可直接使用，需要运营申请
 
         :param request: Request instance for ChannelCreateFlowByFiles.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowByFilesRequest`
@@ -264,6 +330,65 @@ class EssbasicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ChannelDescribeEmployees(self, request):
+        """查询企业员工列表
+
+        :param request: Request instance for ChannelDescribeEmployees.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelDescribeEmployeesRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelDescribeEmployeesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChannelDescribeEmployees", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ChannelDescribeEmployeesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ChannelDescribeOrganizationSeals(self, request):
+        """查询渠道子客企业电子印章，需要操作者具有管理印章权限
+        客户指定需要获取的印章数量和偏移量，数量最多100，超过100按100处理；入参InfoType控制印章是否携带授权人信息，为1则携带，为0则返回的授权人信息为空数组。接口调用成功返回印章的信息列表还有企业印章的总数。
+
+        :param request: Request instance for ChannelDescribeOrganizationSeals.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelDescribeOrganizationSealsRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelDescribeOrganizationSealsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChannelDescribeOrganizationSeals", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ChannelDescribeOrganizationSealsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ChannelGetTaskResultApi(self, request):
         """渠道版查询转换任务状态
 
@@ -293,22 +418,21 @@ class EssbasicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def CreateChannelFlowEvidenceReport(self, request):
-        """【描述】：创建出证报告，返回报告 URL
-        【注意】：此接口需要通过添加白名单获取调用权限，请联系运营人员加白
+    def ChannelVerifyPdf(self, request):
+        """合同文件验签
 
-        :param request: Request instance for CreateChannelFlowEvidenceReport.
-        :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateChannelFlowEvidenceReportRequest`
-        :rtype: :class:`tencentcloud.essbasic.v20210526.models.CreateChannelFlowEvidenceReportResponse`
+        :param request: Request instance for ChannelVerifyPdf.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelVerifyPdfRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelVerifyPdfResponse`
 
         """
         try:
             params = request._serialize()
             headers = request.headers
-            body = self.call("CreateChannelFlowEvidenceReport", params, headers=headers)
+            body = self.call("ChannelVerifyPdf", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
-                model = models.CreateChannelFlowEvidenceReportResponse()
+                model = models.ChannelVerifyPdfResponse()
                 model._deserialize(response["Response"])
                 return model
             else:
@@ -324,8 +448,8 @@ class EssbasicClient(AbstractClient):
 
 
     def CreateConsoleLoginUrl(self, request):
-        """此接口（CreateConsoleLoginUrl）用于创建渠道子客企业控制台Web端登录链接。Web端登录链接是子客控制台的唯一入口。
-        若子客企业未激活，会进入企业激活流程,首次参与激活流程的经办人会成为超管。（若企业激活过程中填写信息有误，需要重置激活流程，可以换一个经办人OpenId获取新的链接进入。）
+        """此接口（CreateConsoleLoginUrl）用于创建渠道子客企业控制台Web/移动登录链接。登录链接是子客控制台的唯一入口。
+        若子客企业未激活，会进入企业激活流程，首次参与激活流程的经办人会成为超管。（若企业激活过程中填写信息有误，需要重置激活流程，可以换一个经办人OpenId获取新的链接进入。）
         若子客企业已激活，使用了新的经办人OpenId进入，则会进入经办人的实名流程。
         若子客企业、经办人均已完成认证，则会直接进入子客Web控制台。
 
@@ -357,6 +481,8 @@ class EssbasicClient(AbstractClient):
 
     def CreateFlowsByTemplates(self, request):
         """接口（CreateFlowsByTemplates）用于使用多个模板批量创建签署流程。当前可批量发起合同（签署流程）数量最大为20个。
+        如若在模板中配置了动态表格, 上传的附件必须为A4大小
+        合同发起人必须在电子签已经进行实名。
 
         :param request: Request instance for CreateFlowsByTemplates.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateFlowsByTemplatesRequest`
@@ -385,7 +511,7 @@ class EssbasicClient(AbstractClient):
 
 
     def CreateSealByImage(self, request):
-        """渠道通过图片为子客代创建印章，图片最大5m；此接口不可直接使用，需要运营申请
+        """渠道通过图片为子客代创建印章，图片最大5m；此接口不可直接使用，请联系运营/客服咨询相关流程
 
         :param request: Request instance for CreateSealByImage.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateSealByImageRequest`
@@ -414,7 +540,23 @@ class EssbasicClient(AbstractClient):
 
 
     def CreateSignUrls(self, request):
-        """创建跳转小程序查看或签署的链接；自动签署的签署方不创建签署链接；
+        """创建跳转小程序查看或签署的链接。
+
+        跳转小程序的几种方式：主要是设置不同的EndPoint
+        1. 通过链接Url直接跳转到小程序，不需要返回
+        设置EndPoint为WEIXINAPP，得到链接打开即可。（与短信提醒用户签署形式一样）。
+        2. 通过链接Url打开H5引导页-->点击跳转到小程序-->签署完退出小程序-->回到H5引导页-->跳转到指定JumpUrl
+        设置EndPoint为CHANNEL，指定JumpUrl，得到链接打开即可。
+        3. 客户App直接跳转到小程序-->小程序签署完成-->返回App
+        跳转到小程序的实现，参考官方文档（分为全屏、半屏两种方式）
+        全屏方式：
+        （https://developers.weixin.qq.com/miniprogram/dev/api/navigate/wx.navigateToMiniProgram.html）
+        半屏方式：
+        （https://developers.weixin.qq.com/miniprogram/dev/framework/open-ability/openEmbeddedMiniProgram.html）
+        其中小程序的原始Id，请联系<对接技术人员>获取，或者查看小程序信息自助获取。
+        使用CreateSignUrls，设置EndPoint为APP，得到path。
+        4. 客户小程序直接跳到电子签小程序-->签署完成退出电子签小程序-->回到客户小程序
+        实现方式同App跳小程序。
 
         :param request: Request instance for CreateSignUrls.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateSignUrlsRequest`
@@ -472,7 +614,8 @@ class EssbasicClient(AbstractClient):
 
 
     def DescribeResourceUrlsByFlows(self, request):
-        """根据签署流程信息批量获取资源下载链接，需合作企业先进行授权
+        """根据签署流程信息批量获取资源下载链接，可以下载签署中、签署完的合同，需合作企业先进行授权。
+        此接口直接返回下载的资源的url，与接口GetDownloadFlowUrl跳转到控制台的下载方式不同。
 
         :param request: Request instance for DescribeResourceUrlsByFlows.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.DescribeResourceUrlsByFlowsRequest`
@@ -501,7 +644,7 @@ class EssbasicClient(AbstractClient):
 
 
     def DescribeTemplates(self, request):
-        """通过此接口（DescribeTemplates）查询该企业在电子签渠道版中配置的有效模板列表
+        """通过此接口（DescribeTemplates）查询该子客企业在电子签拥有的有效模板，不包括渠道模板
 
         :param request: Request instance for DescribeTemplates.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.DescribeTemplatesRequest`
@@ -590,11 +733,11 @@ class EssbasicClient(AbstractClient):
 
 
     def OperateChannelTemplate(self, request):
-        """此接口（OperateChannelTemplate）用于渠道侧将模板库中的模板对合作企业进行查询和设置, 其中包括可见性的修改以及对合作企业的设置.
-        1、同步标识=select时：
-        返回渠道侧模板库当前模板的属性.
-        2、同步标识=update或者delete时：
-        对渠道子客进行模板库中模板授权,修改操作
+        """此接口（OperateChannelTemplate）用于针对渠道模板库中的模板对子客企业可见性的查询和设置，不会直接分配渠道模板给子客企业。
+        1、OperateType=select时：
+        查询渠道模板库
+        2、OperateType=update或者delete时：
+        对子客企业进行模板库中模板可见性的修改、删除操作。
 
         :param request: Request instance for OperateChannelTemplate.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.OperateChannelTemplateRequest`
@@ -625,7 +768,7 @@ class EssbasicClient(AbstractClient):
     def PrepareFlows(self, request):
         """该接口 (PrepareFlows) 用于创建待发起文件
         用户通过该接口进入签署流程发起的确认页面，进行发起信息二次确认， 如果确认则进行正常发起。
-        目前该接口只支持B2C，不建议使用。
+        目前该接口只支持B2C，不建议使用，将会废弃。
 
         :param request: Request instance for PrepareFlows.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.PrepareFlowsRequest`
@@ -714,7 +857,10 @@ class EssbasicClient(AbstractClient):
 
     def UploadFiles(self, request):
         """此接口（UploadFiles）用于文件上传。
-        调用时需要设置Domain 为 file.ess.tencent.cn
+        调用时需要设置Domain, 正式环境为 file.ess.tencent.cn。
+        代码示例：
+        HttpProfile httpProfile = new HttpProfile();
+        httpProfile.setEndpoint("file.test.ess.tencent.cn");
 
         :param request: Request instance for UploadFiles.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.UploadFilesRequest`
